#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hlint
version:              3.2.7
visibility:           public
id:                   hlint-3.2.7-BrpTXc7Cv7NBltfNRH0c6v
key:                  hlint-3.2.7-BrpTXc7Cv7NBltfNRH0c6v
license:              BSD-3-Clause
copyright:            Neil Mitchell 2006-2021
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/hlint#readme
synopsis:             Source code suggestions
description:          HLint gives suggestions on how to improve your source code.
category:             Development
abi:                  be87b913719abdacc26dc809aadbc0d2
exposed:              True
exposed-modules:      Language.Haskell.HLint
hidden-modules:
    Paths_hlint Apply CmdLine Extension Fixity HLint HsColour Idea
    Report Util Parallel Refact Timing CC EmbedData Summary
    Config.Compute Config.Haskell Config.Read Config.Type Config.Yaml
    GHC.All GHC.Util GHC.Util.ApiAnnotation GHC.Util.View
    GHC.Util.Brackets GHC.Util.DynFlags GHC.Util.FreeVars
    GHC.Util.HsDecl GHC.Util.HsExpr GHC.Util.SrcLoc GHC.Util.Scope
    GHC.Util.Unify Hint.All Hint.Bracket Hint.Comment Hint.Duplicate
    Hint.Export Hint.Extensions Hint.Fixities Hint.Import Hint.Lambda
    Hint.List Hint.ListRec Hint.Match Hint.Monad Hint.Naming
    Hint.NewType Hint.Pattern Hint.Pragma Hint.Restrict Hint.Smell
    Hint.Type Hint.Unsafe Test.All Test.Annotations Test.InputOutput
    Test.Util

import-dirs:          /usr/lib/ghc-8.10.5/site-local/hlint-3.2.7
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hlint-3.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hlint
hs-libraries:         HShlint-3.2.7-BrpTXc7Cv7NBltfNRH0c6v
depends:
    aeson-1.5.6.0-IA546NaLWlLGqcowhw6tTs
    ansi-terminal-0.11-366lZebL4UKAFopo4Q1x1i base-4.14.2.0
    bytestring-0.10.12.0 cmdargs-0.10.21-Gp5sk8nLdQ1LCjZIDntuGG
    containers-0.6.4.1 cpphs-1.20.9.1-8u5B4l6K95R8QvpGeHGR6D
    data-default-0.7.1.1-FiQ1o71Il6AF4wrr19xinj directory-1.3.6.0
    extra-1.7.9-HHsi7iW1l3L1a3O3w2D3UA
    file-embed-0.0.14.0-GfeXRY82mmWF3g3U2v7jH5 filepath-1.4.2.1
    filepattern-0.1.2-DSg3wkERMhNJ2fV3brX1w7 ghc-8.10.5 ghc-boot-8.10.5
    ghc-boot-th-8.10.5
    ghc-lib-parser-ex-8.10.0.19-BIWuFKh3rIh2W2Jk6jsxW1
    hscolour-1.24.4-AWTcheqXyydDaCO4ylQ15z process-1.6.9.0
    refact-0.3.0.2-JKNk3jm7RIRD7pQxWgpJCE text-1.2.4.1
    transformers-0.5.6.2 uniplate-1.6.13-HvGjBVisCmDIIHRdDwqYqK
    unordered-containers-0.2.14.0-D9MLkVL2jXfKIhE8RrmI8O
    utf8-string-1.0.2-DMovLmOdbFr3ZT2kNNb9Du
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp
    yaml-0.11.5.0-4Uh3kvrdeuv4NFabdMont6

haddock-interfaces:   /usr/share/doc/hlint/html/hlint.haddock
haddock-html:         /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

